@@ -1,4 +1,9 @@
-#!/usr/bin/python3
+#!/usr/bin/env python3
+
+# SPDX-FileCopyrightText: 2018 Sebastian Wagner
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 """
 TODO: Fix ordering of dicts
@@ -35,7 +40,7 @@ def none_len(arg: Optional[list]):
 def generate_rule(expression: str, identifier: str, name=None):
     return {"rulename": name if name else "%s-%s" % (identifier,
                                                      hashlib.sha1(expression.encode()).hexdigest()[:10]),
-            "if": {"classification.taxonomy": "malicious code",
+            "if": {"classification.taxonomy": "malicious-code",
                    "malware.name": expression
                    },
             "then": {"classification.identifier": identifier, }}
