@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2019 Sebastian Wagner
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 import unittest
 import json
@@ -49,7 +53,7 @@ class TestDownloadMapping(unittest.TestCase):
             mocker.get(URL, text='')
             result = json.loads(main(args))
         self.assertEqual(result,
-                         [{'if': {'classification.taxonomy': 'malicious code',
+                         [{'if': {'classification.taxonomy': 'malicious-code',
                                   'malware.name': '.*'},
                            'rulename': 'default',
                            'then': {'classification.identifier': '{msg[malware.name]}'}}]
@@ -63,13 +67,13 @@ class TestDownloadMapping(unittest.TestCase):
             mocker.get(URL, text='')
             result = json.loads(main(args))
         self.assertEqual(result,
-                         [{'if': {'classification.taxonomy': 'malicious code',
+                         [{'if': {'classification.taxonomy': 'malicious-code',
                                   'malware.name': '.*'},
                            'rulename': 'default',
                            'then': {'classification.identifier': 'constant'}}]
                          )
 
-    maxDiff=None
+    maxDiff = None
 
 
 class TestParser(unittest.TestCase):
