@@ -704,7 +704,7 @@ class IntelMQController():
 
         # set default values for the logging handler
         self.parameters.logging_handler = 'file'
-        self.parameters.logging_path = '/opt/intelmq/var/log'
+        self.parameters.logging_path = DEFAULT_LOGGING_PATH
 
         # Try to get logging_level from defaults configuration, else use default (defined above)
         defaults_loading_exc = None
@@ -1017,14 +1017,20 @@ Get some debugging output on the settings and the environment (to be extended):
         for option, value in utils.get_global_settings().items():
             setattr(self.parameters, option, value)
 
-        # TODO: Rewrite variables with env. variables ( CURRENT IMPLEMENTATION NOT FINAL )
-        # "destination_pipeline_host": "127.0.0.1",
-        # "source_pipeline_host": "127.0.0.1",
-        if os.getenv('INTELMQ_IS_DOCKER', None):
-            pipeline_host = os.getenv('INTELMQ_PIPELINE_HOST')
-            if pipeline_host:
-                setattr(self.parameters, 'destination_pipeline_host', pipeline_host)
-                setattr(self.parameters, 'source_pipeline_host', pipeline_host)
+        # copied from intelmq.lib.bot, should be refactored to e.g. intelmq.lib.config
+        intelmq_environment = [elem for elem in os.environ if elem.startswith('INTELMQ_')]
+        for elem in intelmq_environment:
+            option = elem[8:].lower()
+            value = os.environ[elem]
+            # do some conversions:
+            if value == 'True':
+                value = True
+            elif value == 'False':
+                value = False
+            elif value.isnumeric():
+                value = int(value)
+
+            setattr(self.parameters, option, value)
 
     def run(self):
         results = None
@@ -1132,7 +1138,7 @@ Get some debugging output on the settings and the environment (to be extended):
 
     def _configured_bots_list(self, group=None):
         if group is not None:
-            bots = sorted(k_v[0] for k_v in filter(lambda x: x[1]["group"] == BOT_GROUP[group], self.runtime_configuration.items()))
+            bots = sorted(k_v[0] for k_v in filter(lambda bot: bot[0] != 'global' and bot[1]["group"] == BOT_GROUP[group], self.runtime_configuration.items()))
         else:
             bots = sorted(self.runtime_configuration.keys())
         if 'global' in bots:
