@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2015 National CyberSecurity Center
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 """
 See README for database download.
@@ -8,43 +12,43 @@ import pathlib
 import requests
 
 from intelmq.lib.bot import Bot
-from intelmq import RUNTIME_CONF_FILE
-from intelmq.lib.utils import load_configuration, create_request_session
+from intelmq.lib.utils import get_bots_settings, create_request_session
 from intelmq.bin.intelmqctl import IntelMQController
 
 
 class TorExpertBot(Bot):
+    """Check if the IP address is a Tor Exit Node based on a local database of TOR nodes"""
+    database: str = "/opt/intelmq/var/lib/bots/tor_nodes/tor_nodes.dat"  # TODO: pathlib.Path
+    overwrite: bool = False
 
-    database = set()
+    _database = set()
 
     def init(self):
         self.logger.info("Loading TOR exit node IPs.")
 
         try:
-            with open(self.parameters.database) as fp:
+            with open(self.database) as fp:
                 for line in fp:
                     line = line.strip()
 
                     if len(line) == 0 or line[0] == "#":
                         continue
 
-                    self.database.add(line)
+                    self._database.add(line)
 
         except IOError:
             raise ValueError("TOR rule not defined or failed on open.")
 
-        self.overwrite = getattr(self.parameters, 'overwrite', False)
-
     def process(self):
         event = self.receive_message()
 
         for key in ["source.", "destination."]:
             if key + 'ip' in event:
                 if key + 'tor_node' not in event:
-                    if event.get(key + 'ip') in self.database:
+                    if event.get(key + 'ip') in self._database:
                         event.add(key + 'tor_node', True)
                 elif key + 'tor_node' in event and self.overwrite:
-                    if event.get(key + 'ip') in self.database:
+                    if event.get(key + 'ip') in self._database:
                         event.change(key + 'tor_node', True)
 
         self.send_message(event)
@@ -56,7 +60,7 @@ class TorExpertBot(Bot):
             parsed_args = cls._create_argparser().parse_args()
 
         if parsed_args.update_database:
-            cls.update_database()
+            cls.update_database(verbose=parsed_args.verbose)
 
         else:
             super().run(parsed_args=parsed_args)
@@ -65,12 +69,13 @@ class TorExpertBot(Bot):
     def _create_argparser(cls):
         argparser = super()._create_argparser()
         argparser.add_argument("--update-database", action='store_true', help='downloads latest database data')
+        argparser.add_argument("--verbose", action='store_true', help='be verbose')
         return argparser
 
     @classmethod
-    def update_database(cls):
+    def update_database(cls, verbose=False):
         bots = {}
-        runtime_conf = load_configuration(RUNTIME_CONF_FILE)
+        runtime_conf = get_bots_settings()
         try:
             for bot in runtime_conf:
                 if runtime_conf[bot]["module"] == __name__:
@@ -80,11 +85,13 @@ class TorExpertBot(Bot):
             sys.exit("Database update failed. Your configuration of {0} is missing key {1}.".format(bot, e))
 
         if not bots:
-            print("Database update skipped. No bots of type {0} present in runtime.conf.".format(__name__))
+            if verbose:
+                print("Database update skipped. No bots of type {0} present in runtime.conf.".format(__name__))
             sys.exit(0)
 
         try:
-            print("Downloading the latest database update...")
+            if verbose:
+                print("Downloading the latest database update...")
             session = create_request_session()
             response = session.get("https://check.torproject.org/exit-addresses")
         except requests.exceptions.RequestException as e:
@@ -103,7 +110,8 @@ class TorExpertBot(Bot):
             with open(database_path, "w") as database:
                 database.write(tor_exits)
 
-        print("Database updated. Reloading affected bots.")
+        if verbose:
+            print("Database updated. Reloading affected bots.")
 
         ctl = IntelMQController()
         for bot in bots.keys():
