@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2015 robcza
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 from urllib.parse import urlparse
 
@@ -5,9 +9,8 @@ from intelmq.lib.bot import Bot
 
 
 class Url2fqdnExpertBot(Bot):
-
-    def init(self):
-        self.overwrite = getattr(self.parameters, 'overwrite', False)
+    """Parse the FQDN from the URL"""
+    overwrite = False
 
     def process(self):
         event = self.receive_message()
