@@ -35,7 +35,7 @@ class MISPFeedOutputBot(OutputBot):
     misp_org_name = None
     misp_org_uuid = None
     output_dir: str = "/opt/intelmq/var/lib/bots/mispfeed-output"  # TODO: should be path
-    __is_multithreadable: bool = False
+    _is_multithreadable: bool = False
 
     @staticmethod
     def check_output_dir(dirname):
