@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2015 National CyberSecurity Center
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 import re
 
@@ -9,6 +13,7 @@ REGEX_TIMESTAMP = "# ([^ \t]+ [^ \t]+)"
 
 
 class BruteForceBlockerParserBot(Bot):
+    """Parse the Danger Rulez feed"""
 
     def process(self):
         report = self.receive_message()
