@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2015 National CyberSecurity Center
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 """
 #   DShield.org Suspicious Domain List
@@ -18,6 +22,7 @@ from intelmq.lib.bot import Bot
 
 
 class DshieldDomainParserBot(Bot):
+    """Parse the DShield Suspicious Domains feed"""
 
     def process(self):
         report = self.receive_message()
@@ -34,7 +39,7 @@ class DshieldDomainParserBot(Bot):
 
             event = self.new_event(report)
 
-            event.add('classification.type', 'malware')
+            event.add('classification.type', 'malware-distribution')
             event.add('source.fqdn', row.strip())
             event.add('time.source', time)
             event.add("raw", row)
