@@ -1,3 +1,6 @@
+# SPDX-FileCopyrightText: 2018 by nic.at GmbH
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
 """
 Shodan Stream Parser
 
@@ -584,23 +587,16 @@ CONVERSIONS = {
 
 
 class ShodanParserBot(Bot):
+    """Parse Shodan data collected via the Shodan API"""
+    ignore_errors = True
+    minimal_mode = False
 
-    common_keys = {  # not indicative of type
+    _common_keys = {  # not indicative of type
         '_id', '_shodan', 'asn', 'data', 'device', 'devicetype', 'domains', 'hash',
         'hostnames', 'html', 'ip', 'ip_str', 'isp', 'location', 'opts', 'org',
         'os', 'port', 'tags', 'timestamp', 'transport',
     }
 
-    def init(self):
-        if getattr(self.parameters, 'ignore_errors', True):
-            self.ignore_errors = True
-        else:
-            self.ignore_errors = False
-        if getattr(self.parameters, 'minimal_mode', False):
-            self.minimal_mode = True
-        else:
-            self.minimal_mode = False
-
     def apply_mapping(self, mapping, data, key_path=()):
         self.logger.debug('Applying mapping %r to data %r.', mapping, data)
         event = {}
@@ -650,7 +646,7 @@ class ShodanParserBot(Bot):
             event.add('classification.type', 'other')
             event.add('classification.identifier', 'shodan-scan')
 
-            uncommon_keys = decoded.keys() - self.common_keys
+            uncommon_keys = decoded.keys() - self._common_keys
             event.add('extra.shodan.unique_keys', sorted(uncommon_keys))
             decoded_protocols = PROTOCOLS & uncommon_keys
             if decoded_protocols:
