@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2017 Sebastian Wagner
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 import unittest
 
@@ -28,7 +32,9 @@ class TestSMTPOutputBot(test.BotTestCase, unittest.TestCase):
                          "text": 'foobar',
                          "subject": "type: {ev[classification.type]}",
                          "mail_from": "myself",
-                         "mail_to": "you,yourself"}
+                         "mail_to": "you,yourself",
+                         "starttls": False,
+                         }
 
     def test_event(self):
         self.input_message = EVENT
@@ -45,6 +51,9 @@ class TestSMTPOutputBot(test.BotTestCase, unittest.TestCase):
 ''')
         self.assertEqual({'from_addr': 'myself', 'to_addrs': ['you', 'yourself']},
                          SENT_MESSAGE[1])
+        # https://github.com/certtools/intelmq/issues/2018
+        self.assertIn(('Content-Disposition', 'attachment; filename="events.csv"'),
+                      SENT_MESSAGE[0].get_payload()[1]._headers)
 
     def test_multiple_recipients_event(self):
         """
@@ -67,5 +76,18 @@ class TestSMTPOutputBot(test.BotTestCase, unittest.TestCase):
         self.assertEqual({'from_addr': 'myself', 'to_addrs': ['one@example.com', 'two@example.com']},
                          SENT_MESSAGE[1])
 
+    def test_no_attachment(self):
+        """
+        Assert that no attachment is sent if no fieldname is set
+        """
+        self.input_message = EVENT1
+        with unittest.mock.patch('smtplib.SMTP.send_message', new=send_message):
+            with unittest.mock.patch('smtplib.SMTP.close'):
+                self.run_bot(parameters={'fieldnames': None})
+        self.assertEqual(len(SENT_MESSAGE[0].get_payload()), 1)
+        self.assertIn(('Content-Type', 'text/plain; charset="us-ascii"'),
+                      SENT_MESSAGE[0].get_payload()[0]._headers)
+
+
 if __name__ == '__main__':  # pragma: no cover
     unittest.main()
