@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2019 Sebastian Wagner
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 import os.path
 import unittest
@@ -43,13 +47,13 @@ EVENTS = [{'time.source': '2019-03-22T11:18:52+00:00',
            },
           {'classification.identifier': 'stealrat',
            'malware.name': 'stealrat',
-           'classification.type': 'c2server',
+           'classification.type': 'c2-server',
            'time.source': '2019-03-25T17:47:40+00:00',
            'protocol.transport': 'tcp',
            },
           {'classification.identifier': 'http_post',
            'malware.name': 'http_post',
-           'classification.type': 'c2server',
+           'classification.type': 'c2-server',
            'source.fqdn': 'www.example.com',
            'time.source': '2019-03-25T05:01:47+00:00',
            },
@@ -94,12 +98,12 @@ EVENTS = [{'time.source': '2019-03-22T11:18:52+00:00',
            'protocol.application': 'socks4',
            },
           {'time.source': '2019-03-25T06:29:38+00:00',
-           'classification.type': 'vulnerable service',
+           'classification.type': 'vulnerable-system',
            'classification.identifier': 'dns-open-resolver',
            'protocol.application': 'dns',
            },
           {'time.source': '2020-06-08T18:28:35+00:00',
-           'classification.type': 'vulnerable service',
+           'classification.type': 'vulnerable-system',
            'classification.identifier': 'dns-open-resolver',
            'protocol.application': 'dns',
            },
@@ -160,7 +164,7 @@ EVENTS = [{'time.source': '2019-03-22T11:18:52+00:00',
            'time.source': '2019-09-22T05:39:38+00:00',
            'classification.identifier': 'http_post',
            'malware.name': 'http_post',
-           'classification.type': 'c2server',
+           'classification.type': 'c2-server',
            },
           {'classification.type': 'scanner',
            'classification.identifier': 'scanner',
