@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2016 robcza
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 import os
 import unittest
@@ -29,7 +33,7 @@ EXAMPLE_EVENT = {"feed.name": "Sample CSV Feed",
                  "source.ip": "198.105.221.5",
                  "source.fqdn": "mail5.bulls.unisonplatform.com",
                  "event_description.text": "Really bad actor site comment",
-                 "classification.type": "malware",
+                 "classification.type": "malware-distribution",
                  "raw": utils.base64_encode(SAMPLE_SPLIT[10].replace('\t', ',')+'\r\n'),
                  "time.observation": "2015-01-01T00:00:00+00:00",
                  }
@@ -47,7 +51,7 @@ COMPOSE_EVENT = {"feed.name": "Sample CSV Feed",
                  "source.urlpath": "/foo/",
                  "source.url": "http://example.com/foo/",
                  "source.fqdn": "example.com",
-                 "classification.type": "malware",
+                 "classification.type": "malware-distribution",
                  "raw": utils.base64_encode(COMPOSE_SPLIT[1]+'\r\n'),
                  "time.observation": "2015-01-01T00:00:00+00:00",
                  }
@@ -67,7 +71,7 @@ class TestGenericCsvParserBot(test.BotTestCase, unittest.TestCase):
                                      "__IGNORE__", "source.url", "source.ip",
                                      "source.fqdn", "__IGNORE__"],
                          "delimiter": "\t",
-                         "type": "malware",
+                         "type": "malware-distribution",
                          "default_url_protocol": "http://"}
 
     def test_event(self):
@@ -76,13 +80,18 @@ class TestGenericCsvParserBot(test.BotTestCase, unittest.TestCase):
         self.assertMessageEqual(0, EXAMPLE_EVENT)
         self.assertMessageEqual(1, EXAMPLE_EVENT2)
 
+    def test_time_format_empty_string(self):
+        """ Test if empty string value for parameter time_format is handled correctly. """
+        self.run_bot(parameters={'time_format': ''})
+        self.assertMessageEqual(0, EXAMPLE_EVENT)
+
     def test_strcol(self):
         self.run_bot(parameters={"columns": "time.source, __IGNORE__,"
                                             "event_description.text, __IGNORE__,"
                                             "__IGNORE__, source.url, source.ip,"
                                             "source.fqdn, __IGNORE__",
                                  "delimiter": "\t",
-                                 "type": "malware",
+                                 "type": "malware-distribution",
                                  "column_regex_search": "",
                                  "type_translation": "",
                                  "default_url_protocol": "http://"})
